summaryrefslogtreecommitdiffstats
path: root/kmail/kmmainwidget.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmmainwidget.h')
-rw-r--r--kmail/kmmainwidget.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kmail/kmmainwidget.h b/kmail/kmmainwidget.h
index 1bb3ee06..26e5eee3 100644
--- a/kmail/kmmainwidget.h
+++ b/kmail/kmmainwidget.h
@@ -85,7 +85,7 @@ class KDE_EXPORT KMMainWidget : public TQWidget
TQ_OBJECT
public:
- KMMainWidget(TQWidget *tqparent, const char *name,
+ KMMainWidget(TQWidget *parent, const char *name,
KXMLGUIClient *aGUIClient,
KActionCollection *actionCollection,
KConfig*config = KMKernel::config() );
@@ -262,7 +262,7 @@ protected:
KActionCollection * actionCollection() const { return mActionCollection; }
/** @return the correct config dialog depending on whether the tqparent of the mainWidget
* is a KPart or a KMMainWindow. When dealing with geometries, use this pointer
*/
KConfig * config();
@@ -262,7 +262,7 @@ protected:
KActionCollection * actionCollection() const { return mActionCollection; }
- /** @return the correct config dialog depending on whether the tqparent of the mainWidget
+ /** @return the correct config dialog depending on whether the parent of the mainWidget
* is a KPart or a KMMainWindow. When dealing with geometries, use this pointer
*/